@@ -8,7 +8,7 @@ from oppia.models import Schedule
 
 class UploadCourseForm(forms.Form):
     course_file = forms.FileField(
-                help_text=_('Max size %(size)d Mb') % {'size':int(math.floor(settings.MAX_UPLOAD_SIZE / 1024 / 1024))},
+                help_text=_('Max size %(size)d Mb') % {'size':int(math.floor(settings.OPPIA_MAX_UPLOAD_SIZE / 1024 / 1024))},
                 required=True,
                 error_messages={'required': _('Please select a file to upload')},)
     tags = forms.CharField(
@@ -20,8 +20,8 @@ class UploadCourseForm(forms.Form):
         cleaned_data = super(UploadCourseForm, self).clean()
         file = cleaned_data.get("course_file")
         
-        if file is not None and file._size > settings.MAX_UPLOAD_SIZE:  
-            size = int(math.floor(settings.MAX_UPLOAD_SIZE / 1024 / 1024))
+        if file is not None and file._size > settings.OPPIA_MAX_UPLOAD_SIZE:  
+            size = int(math.floor(settings.OPPIA_MAX_UPLOAD_SIZE / 1024 / 1024))
             raise forms.ValidationError(_("Your file is larger than the maximum allowed (%(size)d Mb). You may want to check your course for large includes, such as images etc.") % {'size':size, })
         
         if file is not None and file.content_type != 'application/zip':
