@@ -31,16 +31,33 @@ def modify(settings):
         'QUIZ_FIRST_ATTEMPT_BONUS':50, # Bonus points for getting over the threshold on first attempt at quiz 
         'QUIZ_CREATED':200, # for creating a quiz
         'ACTIVITY_COMPLETED':10, # for completing an activity
-        'MEDIA_PLAYED':20, # for playing media
+        'MEDIA_STARTED':20, # for starting media
+        'MEDIA_PLAYING_INTERVAL':30, # interval in seconds for which points are given
+        'MEDIA_PLAYING_POINTS_PER_INTERVAL':5, # no points per interval media is playing
+        'MEDIA_MAX_POINTS':200, # the maximum number of points available for any single media play
         'COURSE_DOWNLOADED':50, # for downloading a course
-        }
-       
+    }
+      
+    settings['OPPIA_METADATA'] = {
+        'NETWORK':True, #
+        'DEVICE_ID': True,
+        'SIM_SERIAL': True,
+        'WIFI_ON': True,
+        'NETWORK_CONNECTED': True,
+        'BATTERY_LEVEL': True,
+        'GPS':False,
+    } 
                                           
-    settings['OPPIA_ALLOW_SELF_REGISTRATION'] = True # turns on/off ability for users to self register
+    settings['OPPIA_ALLOW_SELF_REGISTRATION'] = True    # turns on/off ability for users to self register
+    
+    settings['OPPIA_STAFF_ONLY_UPLOAD'] = True          # prevents anyone without is_staff status being able to upload courses,
+                                                        # setting to False allows any registered user to upload a course
     
     settings['OPPIA_GOOGLE_ANALYTICS_ENABLED'] = True
     settings['OPPIA_GOOGLE_ANALYTICS_CODE'] = 'UA-3609005-11'
     settings['OPPIA_GOOGLE_ANALYTICS_DOMAIN'] = 'oppia-mobile.org'
     
     settings['OPPIA_MAX_UPLOAD_SIZE'] = 5242880 # max course file upload size - in bytes
+    
+    settings['OPPIA_POINTS_ENABLED'] = True # determines if the points system is enabled
     
\ No newline at end of file
